@@ -27,7 +27,7 @@
   */
 
 class GeneralCfg : public GeneralCfgDesign  {
-Q_OBJECT
+TQ_OBJECT
 public:
 	GeneralCfg(LMSensors *lsensors, TQWidget *parent=0, const char *name=0);
 	~GeneralCfg();
