@@ -4,7 +4,7 @@
 
 #include "ksensors.h"
 
-#include <ntqlabel.h>
+#include <tqlabel.h>
 
 #include <tdemainwindow.h>
 #include <tdelocale.h>
