@@ -21,7 +21,7 @@
 #include "panel.h"
 #include "qlcdstring.h"
 
-#include <ntqstring.h>
+#include <tqstring.h>
 
 /**
   *@author Miguel Novas
